==> seedsui-react-5.5.92.tgz: package/lib/Input/NumberBox/index.js <==
var _excluded = ["disabled", "plusProps", "minusProps", "inputProps", "defaultValue", "value", "precision", "max", "min", "placeholder", "maxLength", "readOnly", "autoFocus", "autoSelect", "stepFocus", "licon", "liconProps", "ricon", "riconProps", "onClick", "onChange", "onBlur", "onFocus"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeMath.js, 用于解决加减法精度丢失的问题
import React, { forwardRef, useRef, useImperativeHandle, useEffect, useState } from 'react';
import InputNumber from "./../Number"; // 数值框

var NumberBox = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var disabled = _ref.disabled,
      _ref$plusProps = _ref.plusProps,
      plusProps = _ref$plusProps === void 0 ? {} : _ref$plusProps,
      _ref$minusProps = _ref.minusProps,
      minusProps = _ref$minusProps === void 0 ? {} : _ref$minusProps,
      _ref$inputProps = _ref.inputProps,
      inputProps = _ref$inputProps === void 0 ? {} : _ref$inputProps,
      defaultValue = _ref.defaultValue,
      value = _ref.value,
      precision = _ref.precision,
      max = _ref.max,
      min = _ref.min,
      placeholder = _ref.placeholder,
      _ref$maxLength = _ref.maxLength,
      maxLength = _ref$maxLength === void 0 ? '16' : _ref$maxLength,
      readOnly = _ref.readOnly,
      autoFocus = _ref.autoFocus,
      autoSelect = _ref.autoSelect,
      stepFocus = _ref.stepFocus,
      licon = _ref.licon,
      liconProps = _ref.liconProps,
      ricon = _ref.ricon,
      riconProps = _ref.riconProps,
      onClick = _ref.onClick,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var inputRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _inputRef$current;

    return {
      rootDOM: rootRef.current,
      inputDOM: inputRef === null || inputRef === void 0 ? void 0 : inputRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInputDOM: inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.getInputDOM,
      getInputRef: function getInputRef() {
        return inputRef;
      }
    };
  });

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      minDisabled = _useState2[0],
      setMinDisabled = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      maxDisabled = _useState4[0],
      setMaxDisabled = _useState4[1];

  useEffect(function () {
    var inputDOM = _getInputDOM();

    var val = (inputDOM !== null && inputDOM !== void 0 && inputDOM.value ? inputDOM.value : value) || '';
    updateState(val);
  }, [value]); // eslint-disable-line
  // 获取文本框

  function _getInputDOM() {
    var _inputRef$current2;

    if (inputRef !== null && inputRef !== void 0 && (_inputRef$current2 = inputRef.current) !== null && _inputRef$current2 !== void 0 && _inputRef$current2.getInputDOM) {
      return inputRef.current.getInputDOM();
    }

    return null;
  } // 更新禁用状态


  function updateState(val) {
    if (!isNaN(min) && !isNaN(val) && Number(val) <= Number(min)) {
      setMinDisabled(true);
    } else {
      setMinDisabled(false);
    }

    if (!isNaN(max) && !isNaN(val) && Number(val) >= Number(max)) {
      setMaxDisabled(true);
    } else {
      setMaxDisabled(false);
    }
  } // 修改值回调


  function handleChange(val) {
    if (disabled) return;

    var inputDOM = _getInputDOM();

    if (!inputDOM) return; // 非受控组件需要操作DOM

    if (defaultValue || defaultValue === '') {
      inputDOM.value = val;
    }

    updateState(val);
    if (onChange) onChange(val);
  } // 点击减


  function handleMinus(e) {
    e.stopPropagation();
    if (disabled) return;

    var inputDOM = _getInputDOM();

    if (!inputDOM) return;
    var val = inputRef.current.correctNumber(Math.Calc.subtract(inputDOM.value, 1)); // Callback

    handleChange(val);
    if (minusProps.onClick) minusProps.onClick(e, val);

    if (stepFocus) {
      inputDOM.focus();
    }
  } // 点击加


  function handlePlus(e) {
    e.stopPropagation();
    if (disabled) return;

    var inputDOM = _getInputDOM();

    if (!inputDOM) return;
    if (isNaN(inputDOM === null || inputDOM === void 0 ? void 0 : inputDOM.value)) return;
    var val = inputRef.current.correctNumber(Math.Calc.add(inputDOM.value, 1)); // Callback

    handleChange(val);
    if (plusProps.onClick) plusProps.onClick(e, val);

    if (stepFocus) {
      inputDOM.focus();
    }
  } // 文本框属性


  if (!inputProps) {
    inputProps = {};
  }

  inputProps.className = inputProps.className ? "".concat(inputProps.className, " numbox-input") : 'numbox-input'; // render

  function getInputDOM() {
    return /*#__PURE__*/React.createElement(InputNumber, {
      ref: inputRef,
      className: "numbox-input-box",
      type: "number",
      precision: precision,
      inputProps: inputProps,
      defaultValue: defaultValue,
      value: value,
      min: min,
      max: max,
      maxLength: maxLength,
      disabled: disabled,
      readOnly: readOnly,
      placeholder: placeholder,
      onChange: handleChange,
      autoFocus: autoFocus,
      autoSelect: autoSelect,
      onFocus: onFocus,
      onBlur: onBlur
    });
  }

  return /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef
  }, others, {
    disabled: (!isNaN(min) && !isNaN(max) ? Number(min) >= Number(max) : false) || disabled,
    className: "numbox".concat(others.className ? ' ' + others.className : '')
  }), /*#__PURE__*/React.createElement("input", _extends({
    value: "-",
    disabled: minDisabled
  }, plusProps, {
    type: "button",
    className: "numbox-button numbox-button-minus".concat(plusProps.className ? ' ' + plusProps.className : ''),
    onClick: handleMinus
  })), licon && licon, liconProps && !Object.isEmptyObject(liconProps) && /*#__PURE__*/React.createElement("i", _extends({}, liconProps, {
    className: "licon icon".concat(liconProps.className ? ' ' + liconProps.className : '')
  })), getInputDOM(), riconProps && !Object.isEmptyObject(riconProps) && /*#__PURE__*/React.createElement("i", _extends({}, riconProps, {
    className: "ricon icon".concat(riconProps.className ? ' ' + riconProps.className : '')
  })), ricon && ricon, /*#__PURE__*/React.createElement("input", _extends({
    value: "+",
    disabled: maxDisabled
  }, minusProps, {
    type: "button",
    className: "numbox-button numbox-button-plus".concat(minusProps.className ? ' ' + minusProps.className : ''),
    onClick: handlePlus
  })));
});
export default NumberBox;

==> seedsui-react-5.6.52.tgz: package/lib/Input/NumberBox/index.js <==
var _excluded = ["disabled", "plusProps", "minusProps", "inputProps", "defaultValue", "value", "precision", "max", "min", "placeholder", "maxLength", "readOnly", "autoFocus", "autoSelect", "stepFocus", "licon", "liconProps", "ricon", "riconProps", "onClick", "onChange", "onBlur", "onFocus"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeMath.js, 用于解决加减法精度丢失的问题
import React, { forwardRef, useRef, useImperativeHandle, useEffect, useState } from 'react';
import InputNumber from "./../Number"; // 数值框

var NumberBox = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var disabled = _ref.disabled,
      _ref$plusProps = _ref.plusProps,
      plusProps = _ref$plusProps === void 0 ? {} : _ref$plusProps,
      _ref$minusProps = _ref.minusProps,
      minusProps = _ref$minusProps === void 0 ? {} : _ref$minusProps,
      _ref$inputProps = _ref.inputProps,
      inputProps = _ref$inputProps === void 0 ? {} : _ref$inputProps,
      defaultValue = _ref.defaultValue,
      value = _ref.value,
      precision = _ref.precision,
      max = _ref.max,
      min = _ref.min,
      placeholder = _ref.placeholder,
      _ref$maxLength = _ref.maxLength,
      maxLength = _ref$maxLength === void 0 ? '16' : _ref$maxLength,
      readOnly = _ref.readOnly,
      autoFocus = _ref.autoFocus,
      autoSelect = _ref.autoSelect,
      stepFocus = _ref.stepFocus,
      licon = _ref.licon,
      liconProps = _ref.liconProps,
      ricon = _ref.ricon,
      riconProps = _ref.riconProps,
      onClick = _ref.onClick,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var inputRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _inputRef$current;

    return {
      rootDOM: rootRef.current,
      inputDOM: inputRef === null || inputRef === void 0 ? void 0 : inputRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInputDOM: inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.getInputDOM,
      getInputRef: function getInputRef() {
        return inputRef;
      }
    };
  });

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      minDisabled = _useState2[0],
      setMinDisabled = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      maxDisabled = _useState4[0],
      setMaxDisabled = _useState4[1];

  useEffect(function () {
    var inputDOM = _getInputDOM();

    var val = (inputDOM !== null && inputDOM !== void 0 && inputDOM.value ? inputDOM.value : value) || '';
    updateState(val);
  }, [value]); // eslint-disable-line
  // 获取文本框

  function _getInputDOM() {
    var _inputRef$current2;

    if (inputRef !== null && inputRef !== void 0 && (_inputRef$current2 = inputRef.current) !== null && _inputRef$current2 !== void 0 && _inputRef$current2.getInputDOM) {
      return inputRef.current.getInputDOM();
    }

    return null;
  } // 更新禁用状态


  function updateState(val) {
    if (!isNaN(min) && !isNaN(val) && Number(val) <= Number(min)) {
      setMinDisabled(true);
    } else {
      setMinDisabled(false);
    }

    if (!isNaN(max) && !isNaN(val) && Number(val) >= Number(max)) {
      setMaxDisabled(true);
    } else {
      setMaxDisabled(false);
    }
  } // 修改值回调


  function handleChange(val) {
    if (disabled) return;

    var inputDOM = _getInputDOM();

    if (!inputDOM) return; // 非受控组件需要操作DOM

    if (defaultValue || defaultValue === '') {
      inputDOM.value = val;
    }

    updateState(val);
    if (onChange) onChange(val);
  } // 点击减


  function handleMinus(e) {
    e.stopPropagation();
    if (disabled) return;

    var inputDOM = _getInputDOM();

    if (!inputDOM) return;
    var val = inputRef.current.correctNumber(Math.Calc.subtract(inputDOM.value, 1)); // Callback

    handleChange(val);
    if (minusProps.onClick) minusProps.onClick(e, val);

    if (stepFocus) {
      inputDOM.focus();
    }
  } // 点击加


  function handlePlus(e) {
    e.stopPropagation();
    if (disabled) return;

    var inputDOM = _getInputDOM();

    if (!inputDOM) return;
    if (isNaN(inputDOM === null || inputDOM === void 0 ? void 0 : inputDOM.value)) return;
    var val = inputRef.current.correctNumber(Math.Calc.add(inputDOM.value, 1)); // Callback

    handleChange(val);
    if (plusProps.onClick) plusProps.onClick(e, val);

    if (stepFocus) {
      inputDOM.focus();
    }
  } // 文本框属性


  if (!inputProps) {
    inputProps = {};
  }

  inputProps.className = inputProps.className ? "".concat(inputProps.className, " numbox-input") : 'numbox-input'; // render

  function getInputDOM() {
    return /*#__PURE__*/React.createElement(InputNumber, {
      ref: inputRef,
      className: "numbox-input-box",
      type: "number",
      precision: precision,
      inputProps: inputProps,
      defaultValue: defaultValue,
      value: value,
      min: min,
      max: max,
      maxLength: maxLength,
      disabled: disabled,
      readOnly: readOnly,
      placeholder: placeholder,
      onChange: handleChange,
      autoFocus: autoFocus,
      autoSelect: autoSelect,
      onFocus: onFocus,
      onBlur: onBlur
    });
  }

  return /*#__PURE__*/React.createElement("div", _extends({}, others, {
    disabled: (!isNaN(min) && !isNaN(max) ? Number(min) >= Number(max) : false) || disabled,
    className: "numbox".concat(others.className ? ' ' + others.className : ''),
    ref: rootRef
  }), /*#__PURE__*/React.createElement("input", _extends({
    value: "-",
    disabled: minDisabled
  }, plusProps, {
    type: "button",
    className: "numbox-button numbox-button-minus".concat(plusProps.className ? ' ' + plusProps.className : ''),
    onClick: handleMinus
  })), licon && licon, liconProps && !Object.isEmptyObject(liconProps) && /*#__PURE__*/React.createElement("i", _extends({}, liconProps, {
    className: "licon icon".concat(liconProps.className ? ' ' + liconProps.className : '')
  })), getInputDOM(), riconProps && !Object.isEmptyObject(riconProps) && /*#__PURE__*/React.createElement("i", _extends({}, riconProps, {
    className: "ricon icon".concat(riconProps.className ? ' ' + riconProps.className : '')
  })), ricon && ricon, /*#__PURE__*/React.createElement("input", _extends({
    value: "+",
    disabled: maxDisabled
  }, minusProps, {
    type: "button",
    className: "numbox-button numbox-button-plus".concat(minusProps.className ? ' ' + minusProps.className : ''),
    onClick: handlePlus
  })));
});
export default NumberBox;
